import chalk            from 'chalk';
import stripAnsi        from 'strip-ansi';
import { highlightLine } from './formatter.js';

export function formatWithCollapse(lines, options = {}) {
  const clean = raw => stripAnsi(raw).replace(/\[\d+(;\d+)*m/g, '');
  let stack = [], inStack = false, prevIcon = null;
  const out = [];

  for (let raw of lines) {
    const line0 = clean(raw);

    // --filter
    if (options.filter && !line0.toLowerCase().includes(options.filter.toLowerCase())) {
      continue;
    }

    // acumular stack
    if (/^\s*at\s/.test(line0)) {
      stack.push(raw);
      inStack = true;
      continue;
    }

    // al salir de stack, colapsar
    if (inStack) {
      if (stack.length > 3) {
        out.push(chalk.gray(`📦 Stack trace de ${stack.length} líneas colapsado`));
      } else {
        out.push(...stack.map(r => chalk.dim(clean(r))));
      }
      stack = []; inStack = false;
    }

    // coloreamos
    const hl = highlightLine(raw);
    // agrupamos por icono inicial para saltos
    const ic = hl.trim().charAt(0);
    if (prevIcon && ic !== prevIcon) out.push('');
    prevIcon = ic;

    out.push(hl);
  }

  // flush final
  if (stack.length) {
    if (stack.length > 3) {
      out.push(chalk.gray(`📦 Stack trace de ${stack.length} líneas colapsado`));
    } else {
      out.push(...stack.map(r => chalk.dim(clean(r))));
    }
  }

  return out;
}